/**
 * jLim Tiny Plugin
 *
 * @fileOverview
 *    Plugin makes Tiny components accessible with jLim.
 *    Support for TinyAccordion, TinyBox 2, TinySlider 2, TinyFader, TinyDropdown 2, TinyEditor.
 *    Released under MIT license.
 * @version 1.0.0
 * @requires tiny component(s), jlim library
 * @author Victor Villaverde Laan
 * @link http://www.freelancephp.net/jlim-tiny-components-plugin/
 * @link https://github.com/freelancephp/jLim-Tiny-plugin
 */
(function ($) {

$.extend(
	/**
	 * @lends jLim
	 */
	{
		/**
		 * Show tiny dialog box
		 * @param {Object} options
		 */
		tinyBox: function(options) {
			TINY.box.show(options);
		}
	}
);

$.fn.extend(
	/**
	 * @lends jLim.fn
	 */
	{
		/**
		 * Call tiny component method
		 * @param {String} component The tiny component name
		 * @param {String} method The method name to call
		 */
		tiny: function(component, method) {
			var obj = null,
				args = [].slice.call(arguments, 2),
				action = $.trim((component +'-'+ method).toLowerCase());

			// set action
			action = $.trim((component +'-'+ method).toLowerCase());

			// check if tiny component script is available
			if (!TINY[component])
				return alert('Tiny Plugin: No script found for "TINY.'+ component +'".');

			// return object
			if (method == 'object') {
				var el = this.get(0);
				return el && el.__tiny && el.__tiny[component] ? el.__tiny[component] : null;
			}

			// for each element...
			return this.each(function () {
				var opts, sObjRef;

				// set element id when not exists
				if (!this.id)
					this.id = component + Math.random() * 100000000000000000000;

				sObjRef = "jLim('#"+ this.id +"').tiny('"+ component +"', 'object')";

				// create reference on first call
				if (!this.__tiny)
					this.__tiny = {};

				// get object
				obj = this.__tiny[component];

				// check current action
				switch (action) {

				// TinyAccordion
					case 'accordion-expand':
					// args: index (optional)
						obj.pr(1, args[0]);
						break;
					case 'accordion-collapse':
					// args: index (optional)
						obj.pr(-1, args[0]);
						break;
					case 'accordion-init':
					// args: headTag, expandIndependent (optional), indexInitExpand (optional), activeClass (optional)
						args.unshift(this.id);
						obj = new TINY.accordion.slider(sObjRef);
						obj.init.apply(obj, args);
						break;

				// TinySlider
				// TinyFader
					case 'slider-move':
					case 'fader-move':
					// args: relative movement (f.e. 2 or -1)
						obj.move(args[0]);
						break;
					case 'slider-pos':
					case 'fader-pos':
					// args: index
						obj.pos(args[0]);
						break;

				// TinySlider
				// TinyFader
				// TinyDropdown
				// TinyEditor
					case 'slider-init':
					case 'fader-init':
					case 'dropdown-init':
					case 'editor-init':
					// args: options
						// overwrite id option
						opts = $.extend({}, args[0], {id: this.id});

						// call init method
						if (component == 'slider') {
							obj = new TINY.slider.slide(sObjRef, opts);
						} else if (component == 'fader') {
							obj = new TINY.fader.fade(sObjRef, opts);
						} else if (component == 'editor') {
							obj = new TINY.editor.edit(sObjRef, opts);
						} else if (component == 'dropdown') {
							obj = new TINY.dropdown.init(sObjRef, opts);
						}
						break;

					default:
						return;
				}

				// set reference to object
				this.__tiny[component] = obj;
			});
		}
	}
);

})(jLim);
